is_bluetooth_enabled

Function is_bluetooth_enabled 

pub fn is_bluetooth_enabled() -> bool
Available on crate feature unstable only.
Returns the CHIP_VER_DIS_BT eFuse value.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.