pub fn core_count() -> u32Available on crate feature
unstable only.Expand description
Returns the number of CPUs available on the chip.
While ESP32 chips usually come with two mostly equivalent CPUs (protocol CPU and application CPU), the application CPU is unavailable on some.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.