pub fn max_cpu_frequency() -> RateAvailable on crate feature
unstable only.Expand description
Returns the maximum rated clock of the CPU in MHz.
Note that the actual clock may be lower, depending on the current power configuration of the chip, clock source, and other settings.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.